.. AUTO-GENERATED FILE -- DO NOT EDIT!

core.stopwatch
==============

Module: :mod:`core.stopwatch`
-----------------------------
Inheritance diagram for ``zmq.core.stopwatch``:

.. inheritance-diagram:: zmq.core.stopwatch 
   :parts: 3

.. automodule:: zmq.core.stopwatch

.. currentmodule:: zmq.core.stopwatch

:class:`Stopwatch`
------------------


.. autoclass:: Stopwatch
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

